
Libreria OPC UA: 
https://pypi.org/project/asyncua/#description
https://github.com/FreeOpcUa/opcua-asyncio

Libreria base de datos:

TimeScaleDB:
https://pypi.org/project/asyncpg/
https://github.com/MagicStack/asyncpg